@@ -16,12 +16,12 @@ var showModelPrompt = function(self, done) {
       console.log(self.models);
       addModelPrompt(self, done);
     }
-  }).bind(this));  
+  }.bind(self));  
 }
 
 module.exports = {
   ask: function(self) {
-    var done = this.async();
+    var done = self.async();
 
     self.prompt([{
       type: 'confirm',
@@ -34,9 +34,11 @@ module.exports = {
       } else {
         done();
       }
-    }.bind(this));
+    }.bind(self));
   },
-  install: function(self, models, done) {
+  install: function(self) {
+    var models = self.models;
+    var done = self.async();
     for (var i = models.length - 1; i >= 0; i--) {
       var m = models[i];
       var modelFile = self.readFileAsString(path.join(__dirname, '../templates/scripts/model.js'))
