@@ -52,27 +52,6 @@ var showRouteStatePrompt = function(self, done) {
   });
 }
 
-
-/*
-  $stateProvider  // INTRO
-.state('splash', {
-    url: '/splash',
-    templateUrl: 'templates/intro/splash.html',
-    controller: 'SplashCtrl',
-    noAuth: true
-  }).state('intro', {
-    url: '/intro',
-    templateUrl: 'templates/intro/intro.html',
-    controller: 'IntroCtrl',
-    noAuth: true
-  })  // AFTER SIGNUP
-.state('start', {
-    url: '/start',
-    abstract: true,
-    templateUrl: 'templates/start/layout.html',
-    controller: 'StartCtrl'
-  })
-*/
 var generateConfigRoute = function(configRoutes, route) {
   var ctrl = route.state + 'Ctrl.js';
   var view = route.state + '.html';
@@ -86,7 +65,7 @@ var generateConfigRoute = function(configRoutes, route) {
   var ctrlFile = self.readFileAsString(path.join(__dirname, '../templates/scripts/ctrl.js'))
   ctrlFile = ctrlFile.replace("{{APP_NAME}}", self.appName);
   self.write(path.join(self.appPath, ctrl), ctrlFile);
-  this.copy('../templates/views/empty.js', view);
+  self.copy('../templates/views/empty.js', view);
 }
 
 module.exports = {
@@ -104,9 +83,11 @@ module.exports = {
       } else {
         done();
       }
-    }.bind(this));
+    }.bind(self));
   },
-  install: function(self, routes, done) {
+  install: function(self) {
+    var routes = self.routes;
+    var done = self.async();
     var configRoutes = '';
     if (routes.length > 0) {
       configRoutes = '$stateProvider\n';
@@ -120,7 +101,5 @@ module.exports = {
     file = file.replace("{{ROUTES}}", configRoutes);
     self.write(path.join(self.appPath, 'config.js'), file);
     done();
-  },
-
-
+  }
 };
